@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package App::Cronjob;
 # ABSTRACT: wrap up programs to be run as cron jobs
-$App::Cronjob::VERSION = '1.200004';
+$App::Cronjob::VERSION = '1.200005';
 use Digest::MD5 qw(md5_hex);
 use Errno;
 use Fcntl qw( :DEFAULT :flock );
@@ -95,10 +95,11 @@ sub run {
       my $lock_flags = LOCK_EX | LOCK_NB;
 
       unless (flock $lock_fh, $lock_flags) {
+        my $error = $!;
         my $mtime = (stat $lock_fh)[9];
         my $stamp = scalar localtime $mtime;
         die App::Cronjob::Exception->new(
-          lock => "can't lock; locked since $stamp",
+          lock => "can't lock; $!; lockfile created $stamp",
           { locked_since => $mtime },
         );
       }
@@ -233,7 +234,7 @@ END_TEMPLATE
 
 {
   package App::Cronjob::Exception;
-$App::Cronjob::Exception::VERSION = '1.200004';
+$App::Cronjob::Exception::VERSION = '1.200005';
 sub new {
     my ($class, $type, $text, $extra) = @_;
     bless { type => $type, text => $text, extra => $extra } => $class;
@@ -254,7 +255,7 @@ App::Cronjob - wrap up programs to be run as cron jobs
 
 =head1 VERSION
 
-version 1.200004
+version 1.200005
 
 =head1 SEE INSTEAD
 
@@ -270,6 +271,22 @@ For a full description of the program's behavior, consult L<cronjob>.
 
 Ricardo Signes <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords chromatic Mark Jason Dominus
+
+=over 4
+
+=item *
+
+chromatic <chromatic@wgz.org>
+
+=item *
+
+Mark Jason Dominus <mjd@plover.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2009 by Ricardo Signes.
